aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorpmikus <pmikus@cisco.com>2016-11-17 08:38:06 +0100
committerPeter Mikus <pmikus@cisco.com>2016-11-24 20:59:33 +0000
commitf112262b6d3db251fe3171333adc48ee14ebed22 (patch)
tree370a291bd1ba287963a3a73a9b38569775572856
parentcbc22f742633725fb44e4a95b43a301a7da0355c (diff)
Fix documentation and pylint errors
- Fix documentation to be comliant with sphinx - Fix pylint errors Change-Id: I64acaa6c330c5a3b2975efc4120260813a2b3a92 Signed-off-by: pmikus <pmikus@cisco.com>
-rw-r--r--pylint.cfg18
-rw-r--r--resources/libraries/python/DropRateSearch.py80
-rw-r--r--resources/libraries/python/TrafficGenerator.py83
3 files changed, 113 insertions, 68 deletions
diff --git a/pylint.cfg b/pylint.cfg
index 3f94199be0..6052e32da3 100644
--- a/pylint.cfg
+++ b/pylint.cfg
@@ -38,7 +38,7 @@ load-plugins=
# --enable=similarities". If you want to run only the classes checker, but have
# no Warning level messages displayed, use"--disable=all --enable=classes
# --disable=W"
-#disable=
+disable=redefined-variable-type
[REPORTS]
@@ -182,7 +182,7 @@ docstring-min-length=-1
[MISCELLANEOUS]
# List of note tags to take in consideration, separated by a comma.
-notes=FIXME,XXX,TODO
+notes=FIXME
[TYPECHECK]
@@ -242,35 +242,35 @@ int-import-graph=
[DESIGN]
# Maximum number of arguments for function / method
-max-args=7
+max-args=10
# Argument names that match this expression will be ignored. Default to name
# with leading underscore
ignored-argument-names=_.*
# Maximum number of locals for function / method body
-max-locals=15
+max-locals=20
# Maximum number of return / yield for function / method body
max-returns=6
# Maximum number of branch for function / method body
-max-branches=12
+max-branches=20
# Maximum number of statements in function / method body
-max-statements=50
+max-statements=60
# Maximum number of parents for a class (see R0901).
max-parents=7
# Maximum number of attributes for a class (see R0902).
-max-attributes=7
+max-attributes=10
# Minimum number of public methods for a class (see R0903).
-min-public-methods=2
+min-public-methods=0
# Maximum number of public methods for a class (see R0904).
-max-public-methods=20
+max-public-methods=50
[EXCEPTIONS]
diff --git a/resources/libraries/python/DropRateSearch.py b/resources/libraries/python/DropRateSearch.py
index aead532da0..354e7d493c 100644
--- a/resources/libraries/python/DropRateSearch.py
+++ b/resources/libraries/python/DropRateSearch.py
@@ -102,7 +102,7 @@ class DropRateSearch(object):
def get_latency(self):
"""Return min/avg/max latency.
- :return: Latency stats.
+ :returns: Latency stats.
:rtype: list
"""
pass
@@ -122,7 +122,7 @@ class DropRateSearch(object):
:type loss_acceptance: float
:type loss_acceptance_type: LossAcceptanceType
:type traffic_type: str
- :return: Drop threshold exceeded? (True/False)
+ :returns: Drop threshold exceeded? (True/False)
:rtype bool
"""
pass
@@ -134,7 +134,8 @@ class DropRateSearch(object):
:param min_rate: Lower value of search boundaries.
:type max_rate: float
:type min_rate: float
- :return: nothing
+ :returns: nothing
+ :raises: ValueError if min rate is lower than 0 and higher than max rate
"""
if float(min_rate) <= 0:
raise ValueError("min_rate must be higher than 0")
@@ -149,7 +150,8 @@ class DropRateSearch(object):
:param loss_acceptance: Loss acceptance treshold for PDR search.
:type loss_acceptance: str
- :return: nothing
+ :returns: nothing
+ :raises: ValueError if loss acceptance is lower than zero
"""
if float(loss_acceptance) < 0:
raise ValueError("Loss acceptance must be higher or equal 0")
@@ -159,7 +161,7 @@ class DropRateSearch(object):
def get_loss_acceptance(self):
"""Return configured loss acceptance treshold.
- :return: Loss acceptance treshold.
+ :returns: Loss acceptance treshold.
:rtype: float
"""
return self._loss_acceptance
@@ -167,14 +169,14 @@ class DropRateSearch(object):
def set_loss_acceptance_type_percentage(self):
"""Set loss acceptance treshold type to percentage.
- :return: nothing
+ :returns: nothing
"""
self._loss_acceptance_type = LossAcceptanceType.PERCENTAGE
def set_loss_acceptance_type_frames(self):
"""Set loss acceptance treshold type to frames.
- :return: nothing
+ :returns: nothing
"""
self._loss_acceptance_type = LossAcceptanceType.FRAMES
@@ -182,7 +184,7 @@ class DropRateSearch(object):
"""Return true if loss acceptance treshold type is percentage,
false otherwise.
- :return: True if loss acceptance treshold type is percentage.
+ :returns: True if loss acceptance treshold type is percentage.
:rtype: boolean
"""
return self._loss_acceptance_type == LossAcceptanceType.PERCENTAGE
@@ -192,28 +194,28 @@ class DropRateSearch(object):
:param step_rate: Linear search step size.
:type step_rate: float
- :return: nothing
+ :returns: nothing
"""
self._rate_linear_step = float(step_rate)
def set_search_rate_type_percentage(self):
"""Set rate type to percentage of linerate.
- :return: nothing
+ :returns: nothing
"""
self._set_search_rate_type(RateType.PERCENTAGE)
def set_search_rate_type_bps(self):
"""Set rate type to bits per second.
- :return: nothing
+ :returns: nothing
"""
self._set_search_rate_type(RateType.BITS_PER_SECOND)
def set_search_rate_type_pps(self):
"""Set rate type to packets per second.
- :return: nothing
+ :returns: nothing
"""
self._set_search_rate_type(RateType.PACKETS_PER_SECOND)
@@ -222,7 +224,8 @@ class DropRateSearch(object):
:param rate_type: Type of rate to set.
:type rate_type: RateType
- :return: nothing
+ :returns: nothing
+ :raises: Exception if rate type is unknown
"""
if rate_type not in RateType:
raise Exception("rate_type unknown: {}".format(rate_type))
@@ -234,7 +237,7 @@ class DropRateSearch(object):
:param frame_size: Size of frames.
:type frame_size: str
- :return: nothing
+ :returns: nothing
"""
self._frame_size = frame_size
@@ -243,14 +246,14 @@ class DropRateSearch(object):
:param duration: Number of seconds for traffic to run.
:type duration: int
- :return: nothing
+ :returns: nothing
"""
self._duration = int(duration)
def get_duration(self):
"""Return configured duration of single traffic run.
- :return: Number of seconds for traffic to run.
+ :returns: Number of seconds for traffic to run.
:rtype: int
"""
return self._duration
@@ -260,14 +263,14 @@ class DropRateSearch(object):
:param convergence: Treshold value number.
:type convergence: float
- :return: nothing
+ :returns: nothing
"""
self._binary_convergence_threshold = float(convergence)
def get_binary_convergence_threshold(self):
"""Get convergence for binary search.
- :return: Treshold value number.
+ :returns: Treshold value number.
:rtype: float
"""
return self._binary_convergence_threshold
@@ -275,8 +278,9 @@ class DropRateSearch(object):
def get_rate_type_str(self):
"""Return rate type representation.
- :return: String representation of rate type.
+ :returns: String representation of rate type.
:rtype: str
+ :raises: ValueError if rate type is unknown
"""
if self._rate_type == RateType.PERCENTAGE:
return "%"
@@ -292,17 +296,18 @@ class DropRateSearch(object):
:param max_attempts: Number of traffic runs.
:type max_attempts: int
- :return: nothing
+ :returns: nothing
+ :raises: ValueError if max attempts is lower than zero
"""
if int(max_attempts) > 0:
self._max_attempts = int(max_attempts)
else:
- raise ValueError("Max attempt must by greater then zero")
+ raise ValueError("Max attempt must by greater than zero")
def get_max_attempts(self):
"""Return maximum number of traffic runs during one rate step.
- :return: Number of traffic runs.
+ :returns: Number of traffic runs.
:rtype: int
"""
return self._max_attempts
@@ -310,14 +315,14 @@ class DropRateSearch(object):
def set_search_result_type_best_of_n(self):
"""Set type of search result evaluation to Best of N.
- :return: nothing
+ :returns: nothing
"""
self._set_search_result_type(SearchResultType.BEST_OF_N)
def set_search_result_type_worst_of_n(self):
"""Set type of search result evaluation to Worst of N.
- :return: nothing
+ :returns: nothing
"""
self._set_search_result_type(SearchResultType.WORST_OF_N)
@@ -326,7 +331,8 @@ class DropRateSearch(object):
:param search_type: Type of search result evaluation to set.
:type search_type: SearchResultType
- :return: nothing
+ :returns: nothing
+ :raises: ValueError if search type is unknown
"""
if search_type not in SearchResultType:
raise ValueError("search_type unknown: {}".format(search_type))
@@ -339,7 +345,7 @@ class DropRateSearch(object):
:param res_list: List of return values from all runs at one rate step.
:type res_list: list
- :return: True if at least one run is True, False otherwise.
+ :returns: True if at least one run is True, False otherwise.
:rtype: boolean
"""
# Return True if any element of the iterable is True.
@@ -351,7 +357,7 @@ class DropRateSearch(object):
:param res_list: List of return values from all runs at one rate step.
:type res_list: list
- :return: False if at least one run is False, True otherwise.
+ :returns: False if at least one run is False, True otherwise.
:rtype: boolean
"""
# Return False if not all elements of the iterable are True.
@@ -362,8 +368,9 @@ class DropRateSearch(object):
:param res_list: List of return values from all runs at one rate step.
:type res_list: list
- :return: Boolean based on search result type.
+ :returns: Boolean based on search result type.
:rtype: boolean
+ :raises: ValueError if search result type is unknown
"""
if self._search_result_type == SearchResultType.BEST_OF_N:
return self._get_best_of_n(res_list)
@@ -379,7 +386,8 @@ class DropRateSearch(object):
:param traffic_type: Traffic profile.
:type start_rate: float
:type traffic_type: str
- :return: nothing
+ :returns: nothing
+ :raises: ValueError if start rate is not in range
"""
if not self._rate_min <= float(start_rate) <= self._rate_max:
@@ -462,8 +470,9 @@ class DropRateSearch(object):
def verify_search_result(self):
"""Fail if search was not successful.
- :return: Result rate and latency stats.
+ :returns: Result rate and latency stats.
:rtype: tuple
+ :raises: Exception if search failed
"""
if self._search_result == SearchResults.FAILURE:
raise Exception('Search FAILED')
@@ -482,7 +491,8 @@ class DropRateSearch(object):
:type b_max: float
:type traffic_type: str
:type skip_max_rate: bool
- :return: nothing
+ :returns: nothing
+ :raises: ValueError if input values are not valid
"""
if not self._rate_min <= float(b_min) <= self._rate_max:
@@ -498,7 +508,7 @@ class DropRateSearch(object):
rate = ((float(b_max) - float(b_min)) / 2) + float(b_min)
else:
# rate is max of interval
- rate = float(b_max)
+ rate = float(b_max)
# rate diff with previous run
rate_diff = abs(self._last_binary_rate - rate)
@@ -536,7 +546,8 @@ class DropRateSearch(object):
:param traffic_type: Traffic profile.
:type start_rate: float
:type traffic_type: str
- :return: nothing
+ :returns: nothing
+ :raises: RuntimeError if linear search failed
"""
self.linear_search(start_rate, traffic_type)
@@ -583,9 +594,10 @@ class DropRateSearch(object):
:type num_b: float
:type rel_tol: float
:type abs_tol: float
- :return: Returns True if num_a is close in value to num_b or equal.
+ :returns: Returns True if num_a is close in value to num_b or equal.
False otherwise.
:rtype: boolean
+ :raises: ValueError if input values are not valid
"""
if num_a == num_b:
diff --git a/resources/libraries/python/TrafficGenerator.py b/resources/libraries/python/TrafficGenerator.py
index 307a28f470..87437d8284 100644
--- a/resources/libraries/python/TrafficGenerator.py
+++ b/resources/libraries/python/TrafficGenerator.py
@@ -34,14 +34,30 @@ class TGDropRateSearchImpl(DropRateSearch):
def measure_loss(self, rate, frame_size, loss_acceptance,
loss_acceptance_type, traffic_type):
-
+ """Runs the traffic and evaluate the measured results.
+
+ :param rate: Offered traffic load.
+ :param frame_size: Size of frame.
+ :param loss_acceptance: Permitted drop ratio or frames count.
+ :param loss_acceptance_type: Type of permitted loss.
+ :param traffic_type: Traffic profile ([2,3]-node-L[2,3], ...).
+ :type rate: int
+ :type frame_size: str
+ :type loss_acceptance: float
+ :type loss_acceptance_type: LossAcceptanceType
+ :type traffic_type: str
+ :returns: Drop threshold exceeded? (True/False)
+ :rtype: bool
+ :raises: NotImplementedError if TG is not supported.
+ :raises: RuntimeError if TG is not specified.
+ """
# we need instance of TrafficGenerator instantiated by Robot Framework
# to be able to use trex_stl-*()
tg_instance = BuiltIn().get_library_instance(
'resources.libraries.python.TrafficGenerator')
if tg_instance._node['subtype'] is None:
- raise Exception('TG subtype not defined')
+ raise RuntimeError('TG subtype not defined')
elif tg_instance._node['subtype'] == NodeSubTypeTG.TREX:
unit_rate = str(rate) + self.get_rate_type_str()
tg_instance.trex_stl_start_remote_exec(self.get_duration(),
@@ -52,7 +68,6 @@ class TGDropRateSearchImpl(DropRateSearch):
if self.loss_acceptance_type_is_percentage():
loss = (float(loss) / float(sent)) * 100
- # TODO: getters for tg_instance
logger.trace("comparing: {} < {} {}".format(loss,
loss_acceptance,
loss_acceptance_type))
@@ -64,12 +79,11 @@ class TGDropRateSearchImpl(DropRateSearch):
raise NotImplementedError("TG subtype not supported")
def get_latency(self):
- """Return min/avg/max latency.
+ """Returns min/avg/max latency.
- :return: Latency stats.
+ :returns: Latency stats.
:rtype: list
"""
-
tg_instance = BuiltIn().get_library_instance(
'resources.libraries.python.TrafficGenerator')
return tg_instance.get_latency_int()
@@ -93,7 +107,7 @@ class TrafficGenerator(object):
def get_loss(self):
"""Return number of lost packets.
- :return: Number of lost packets.
+ :returns: Number of lost packets.
:rtype: str
"""
return self._loss
@@ -101,7 +115,7 @@ class TrafficGenerator(object):
def get_sent(self):
"""Return number of sent packets.
- :return: Number of sent packets.
+ :returns: Number of sent packets.
:rtype: str
"""
return self._sent
@@ -109,7 +123,7 @@ class TrafficGenerator(object):
def get_received(self):
"""Return number of received packets.
- :return: Number of received packets.
+ :returns: Number of received packets.
:rtype: str
"""
return self._received
@@ -117,12 +131,11 @@ class TrafficGenerator(object):
def get_latency_int(self):
"""Return rounded min/avg/max latency.
- :return: Latency stats.
+ :returns: Latency stats.
:rtype: list
"""
return self._latency
- #pylint: disable=too-many-arguments, too-many-locals
def initialize_traffic_generator(self, tg_node, tg_if1, tg_if2,
tg_if1_adj_node, tg_if1_adj_if,
tg_if2_adj_node, tg_if2_adj_if,
@@ -136,7 +149,7 @@ class TrafficGenerator(object):
:param tg_if1_adj_if: TG if1 adjecent interface.
:param tg_if2_adj_node: TG if2 adjecent node.
:param tg_if2_adj_if: TG if2 adjecent interface.
- :test_type: 'L2' or 'L3' - src/dst MAC address.
+ :param test_type: 'L2' or 'L3' - src/dst MAC address.
:type tg_node: dict
:type tg_if1: str
:type tg_if2: str
@@ -145,13 +158,14 @@ class TrafficGenerator(object):
:type tg_if2_adj_node: dict
:type tg_if2_adj_if: str
:type test_type: str
- :return: nothing
+ :returns: nothing
+ :raises: RuntimeError in case of issue during initialization.
"""
topo = Topology()
if tg_node['type'] != NodeType.TG:
- raise Exception('Node type is not a TG')
+ raise RuntimeError('Node type is not a TG')
self._node = tg_node
if tg_node['subtype'] == NodeSubTypeTG.TREX:
@@ -259,10 +273,12 @@ class TrafficGenerator(object):
:param node: Traffic generator node.
:type node: dict
- :return: nothing
+ :returns: nothing
+ :raises: RuntimeError if T-rex teardown failed.
+ :raises: RuntimeError if node type is not a TG.
"""
if node['type'] != NodeType.TG:
- raise Exception('Node type is not a TG')
+ raise RuntimeError('Node type is not a TG')
if node['subtype'] == NodeSubTypeTG.TREX:
ssh = SSH()
ssh.connect(node)
@@ -278,7 +294,8 @@ class TrafficGenerator(object):
:param node: T-REX generator node.
:type node: dict
- :return: Nothing
+ :returns: Nothing
+ :raises: RuntimeError if stop traffic script fails.
"""
ssh = SSH()
ssh.connect(node)
@@ -312,7 +329,9 @@ class TrafficGenerator(object):
:type async_call: bool
:type latency: bool
:type warmup_time: int
- :return: Nothing
+ :returns: Nothing
+ :raises: NotImplementedError if traffic type is not supported.
+ :raises: RuntimeError in case of TG driver issue.
"""
ssh = SSH()
ssh.connect(self._node)
@@ -491,9 +510,10 @@ class TrafficGenerator(object):
self._latency.append(self._result.split(', ')[5].split('=')[1])
def stop_traffic_on_tg(self):
"""Stop all traffic on TG
:return: Nothing
"""
if self._node is None:
raise RuntimeError("TG is not set")
@@ -509,14 +529,21 @@ class TrafficGenerator(object):
:param rate: Offered load per interface (e.g. 1%, 3gbps, 4mpps, ...).
:param framesize: Frame size (L2) in Bytes.
:param traffic_type: Traffic profile.
+ :param warmup_time: Warmup phase in seconds.
+ :param async_call: Async mode.
:param latency: With latency measurement.
:type duration: str
:type rate: str
:type framesize: str
:type traffic_type: str
+ :type warmup_time: int
+ :type async_call: bool
:type latency: bool
- :return: TG output.
+ :returns: TG output.
:rtype: str
+ :raises: RuntimeError if TG is not set.
+ :raises: RuntimeError if node is not TG or subtype is not specified.
+ :raises: NotImplementedError if TG is not supported.
"""
node = self._node
@@ -524,10 +551,10 @@ class TrafficGenerator(object):
raise RuntimeError("TG is not set")
if node['type'] != NodeType.TG:
- raise Exception('Node type is not a TG')
+ raise RuntimeError('Node type is not a TG')
if node['subtype'] is None:
- raise Exception('TG subtype not defined')
+ raise RuntimeError('TG subtype not defined')
elif node['subtype'] == NodeSubTypeTG.TREX:
self.trex_stl_start_remote_exec(duration, rate, framesize,
traffic_type, async_call, latency,
@@ -540,7 +567,8 @@ class TrafficGenerator(object):
def no_traffic_loss_occurred(self):
"""Fail if loss occurred in traffic run.
- :return: nothing
+ :returns: nothing
+ :raises: Exception if loss occured.
"""
if self._loss is None:
raise Exception('The traffic generation has not been issued')
@@ -551,7 +579,12 @@ class TrafficGenerator(object):
loss_acceptance_type):
"""Fail if loss is higher then accepted in traffic run.
- :return: nothing
+ :param loss_acceptance: Permitted drop ratio or frames count.
+ :param loss_acceptance_type: Type of permitted loss.
+ :type loss_acceptance: float
+ :type loss_acceptance_type: LossAcceptanceType
+ :returns: nothing
+ :raises: Exception if loss is above acceptance criteria.
"""
if self._loss is None:
raise Exception('The traffic generation has not been issued')
@@ -491,9 +510,10 @@ class TrafficGenerator(object):
self._latency.append(self._result.split(', ')[5].split('=')[1])
def stop_traffic_on_tg(self):
- """Stop all traffic on TG
+ """Stop all traffic on TG.
- :return: Nothing
+ :returns: Nothing
+ :raises: RuntimeError if TG is not set.
"""
if self._node is None: